@@ -59,7 +59,7 @@ Selector::Selector(Lum::Model::Int* minutes, Lum::Model::Int *seconds)
   Observe(GetClosedAction());
 }
 
-void Selector::PreInit()
+Lum::Object* Selector::GetContent()
 {
   Lum::Label            *label;
   Lum::Panel            *panel,*horiz;
@@ -68,7 +68,7 @@ void Selector::PreInit()
   Lum::TextValue        *value;
   Lum::Model::HeaderRef headerModel;
 
-  panel=Lum::VPanel::Create();
+  panel=Lum::VPanel::Create(true,true);
 
   label=Lum::Label::Create(true,true);
 
@@ -120,12 +120,13 @@ void Selector::PreInit()
   horiz->Add(table);
 
   panel->Add(horiz);
-  panel->AddSpace();
-  panel->Add(Lum::ButtonRow::CreateOkCancel(okAction,GetClosedAction(),true,false));
 
-  SetMain(panel);
+  return panel;
+}
 
-  Dialog::PreInit();
+void Selector::GetActions(std::vector<Lum::Dlg::ActionInfo>& actions)
+{
+  Lum::Dlg::ActionDialog::CreateActionInfosOkCancel(actions,okAction,GetClosedAction());
 }
 
 void Selector::Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg)
